/* ccgo: ccgo.cc
 * 
 * Copyright 2002 Chun-Chung Chen <cjj@u.washington.edu>
 * 
 * This program is free software; you can redistribute it and'or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include "view_win.hh"
#include "game_setup.hh"
#include "igs/win.hh"
#include "settings.hh"
#include <gtkmm/box.h>
#include <gtkmm/window.h>
#include <gtkmm/main.h>
#include <gtkmm/fileselection.h>
#include <gtkmm/stock.h>
#include <gconfmm/init.h>
#include <iostream>
#include <fstream>

class ccGo :
	public Gtk::Window
{
	Gtk::FileSelection * filesel;
	go::GameSetup * setup;
	void open_sgf();
	void open_sgf_done();
	void new_game();
	void open_igs();
public:
	ccGo();
	~ccGo();
};

void ccGo::open_sgf()
{
	if (! filesel) {
		filesel = new Gtk::FileSelection("load sgf file");
		filesel->hide_fileop_buttons();
		filesel->get_cancel_button()->signal_clicked().connect(slot(* filesel, & Widget::hide));
		filesel->get_ok_button()->signal_clicked().connect(slot(* this, & ccGo::open_sgf_done));
	}
	filesel->show_all();
}

void ccGo::open_sgf_done()
{
	if (! filesel) return;
	std::string fn = filesel->get_filename();
	filesel->hide();
	new go::ViewWin(fn);
}

void ccGo::new_game()
{
	if (! setup) {
		setup = new go::GameSetup();
	}
	setup->show_all();
}

void ccGo::open_igs()
{
	new igs::Win("telnet igs.joyjoy.net 6969");
}

ccGo::ccGo() :
	filesel(0),
	setup(0)
{
	Gtk::VBox * vb;
	Gtk::Label * lb;
	Gtk::Button *bt;
	vb = Gtk::manage(new Gtk::VBox);
	add(* vb);
	lb = Gtk::manage(new Gtk::Label("ccGo"));
	vb->pack_start(* lb, Gtk::PACK_SHRINK);
	bt = Gtk::manage(new Gtk::Button("Load sgf file"));
	vb->pack_start(* bt, Gtk::PACK_SHRINK);
	bt->signal_clicked().connect(slot(* this, & ccGo::open_sgf));
	bt = Gtk::manage(new Gtk::Button("New game"));
	vb->pack_start(* bt, Gtk::PACK_SHRINK);
	bt->signal_clicked().connect(slot(* this, & ccGo::new_game));
	bt = Gtk::manage(new Gtk::Button("Connect to IGS"));
	vb->pack_start(* bt, Gtk::PACK_SHRINK);
	bt->signal_clicked().connect(slot(* this, & ccGo::open_igs));
	bt = Gtk::manage(new Gtk::Button(Gtk::Stock::QUIT));
	vb->pack_start(* bt, Gtk::PACK_SHRINK);
	bt->signal_clicked().connect(slot(* this, & Window::hide));
}

ccGo::~ccGo()
{
	if (filesel) delete filesel;
	if (setup) delete setup;
}

int main(int argc, char * argv[], char * envp[])
{
	Gtk::Main m(& argc, & argv);
	go::settings.init();
	go::settings.command_line(argc, argv, envp);

	ccGo ccgo;
	ccgo.show_all();

	Gtk::Main::run(ccgo);

	return 0;
}
